@@ -242,13 +242,11 @@ def set_bv_discrete_target_column(df,bins):
         raise Exception('No BV column found!!!!!')
     return df
 
-def set_target_column(df,model_type,bins):
+def set_target_column(df,model_type):
     if model_type == 'probability':
         df = set_idemailstatus_target_column( df=df )
     elif model_type == 'bv':
         df = set_bv_target_column( df=df )
-    elif model_type == 'multiclass':
-        df = set_bv_discrete_target_column( df=df,bins=bins )
     elif model_type == 'bvfake':
         df = set_bv_fake_column( df=df )
     else:
